<!DOCTYPE TS><TS>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation>カット (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation>コピー (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation>ペースト (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation>アンドゥ (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation>リドゥ (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation>累乗 (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation>括弧 (()</translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation>絶対値 (|)</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation>分数 (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation>ルート (Ctrl + 2)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation>Distance {%1} {%2}</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation>Circumference {%1}</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation>Length {%1}</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation>Radius {%1}</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation>Arc Angle {%1}</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation>Angle {%1}{%2}{%3}</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation>Ratio {%1}/{%2}</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation>Slope {%1}</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation>Area {%1}</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation>Point</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Segment</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation>Ray</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Line</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Circle</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>Arc</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Polygon</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation>Circle Interior</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation>Arc Sector</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation>Arc Segment</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation>Locus</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation>Measurement</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation>Calculation</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Annotation</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation>undefined</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation>値は未定義です</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation>値は %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation>%1 %2 を挿入</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>レディ</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation>Loop on %1</translation>
    </message>
    <message>
        <source>Given</source>
        <translation>Given</translation>
    </message>
    <message>
        <source>Final</source>
        <translation>Final</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation>Initial</translation>
    </message>
    <message>
        <source>or</source>
        <translation>or</translation>
    </message>
    <message>
        <source>final</source>
        <translation>final</translation>
    </message>
    <message>
        <source>initial</source>
        <translation>initial</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation>not constructed</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation>doesn&apos;t exist</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation>hidden</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation>%1 is the translation of %2 by the vector from %3 to %4</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation>%1 is the rotation of %2 about %3 by angle %4</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation>%1 is the image of %2 scaled about %3 by the ratio %4:%5</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation>%1 is the image of %2 scaled about %3 by ratio %4</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation>%1 is the reflection of %2 about %3</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation>%1 is free</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation>%1 is on %2</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation>%1 is the intersection of %2 and %3</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation>%1 is the 2nd intersection of %2 and %3</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation>%1 is the midpoint of %2</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation>%1 has endpoints %2 and %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation>%1 is from %2 through %3</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation>%1 bisects angle %2 %3 %4</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation>%1 is between %2 and %3</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation>%1 is parallel to %2 through %3</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation>%1 is perpendicular to %2 through %3</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation>%1 is centered at %2 and passes through %3</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation>%1 has center at %2 and radius %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation>%1 passes through points %2, %3, and %4</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation>%1 is traced by %2, driven by %3</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation>%1 involves %2</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation>%1 is the distance between %2 and %3</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation>%1 is the length of %2</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation>%1 is the radius of %2</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation>%1 is the angle of %2</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation>%1 is the angle between points %1, %2, and %3</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation>%1 is the ratio of %2 to %3</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation>%1 is the slope of %2</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation>%1 is the area of %2</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation>%1 is defined by %2</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation>%1 has vertices at points %2</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation>KSEG 設定</translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation>背景色</translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation>前景色(既定値)</translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation>選択状態の表示方法</translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation>境界線で囲む</translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation>点滅させる</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation>再帰の深さを入力:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation>現在の設定では生成されるオブジェクトが多すぎます。</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation>現在の設定では %1 個のオブジェクトが生成されます。</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation>Samples in locus:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation>選択</translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation>選択解除</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation>新規グループ</translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation>グループ削除</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation>不可視
アイテム
にも影響</translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation>SHIFTを押したままクリックすると現在の選択に追加されます</translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation>「すべての&lt;Type&gt;」グループも不可視オブジェクトを選択(あるいは解除)します</translation>
    </message>
    <message>
        <source>All Points</source>
        <translation>すべてのPoint</translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation>すべてのSegment</translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation>すべてのRay</translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation>すべてのLine</translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation>すべてのCircle</translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation>すべてのArc</translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation>すべてのPolygon</translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation>すべてのCircle Interior</translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation>すべてのArc Sector</translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation>すべてのArc Segment</translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation>すべてのLocus</translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation>すべてのMeasurement</translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation>すべてのCalculation</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>新しいグループ名を入力:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation>選択したグループを本当に削除しますか?</translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation>Untitled</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>レディ</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation>%1 %2 のラベルを移動</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation>%1 %2 を選択</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation>%1 %2 を選択解除</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation>さらに %1 %2 を選択</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation>選択されたオブジェクトを移動</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation>%1 %2 の束縛を解除</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation>%1 %2 を %3 %4 上に束縛</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation>%1 %2 を %3 %4 と %5 %6 の交点に束縛</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation>新規スケッチ(&amp;N)</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation>新規コンストラクション(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>開く(&amp;O)...</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation>現在のウィンドウで開く...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>名前を付けて保存(&amp;A)...</translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation>コンストラクションとしてコピー</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>印刷(&amp;P)...</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation>言語の選択(&amp;L)...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation>その他(&amp;O)...</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>色(&amp;C)</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation>線のスタイル(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation>点のスタイル(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>フォント(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation>フォント(&amp;F)...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>元に戻す(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>やり直す(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation>オブジェクトを削除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation>オブジェクトを削除(&amp;D)</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation>ラベルをトグル(&amp;L)</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation>ラベルをトグル(&amp;L)</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation>ラベルを隠す</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation>ラベルを隠す</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation>ラベルを表示</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation>ラベルを表示</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation>ラベルを変更(&amp;b)...</translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation>オブジェクトを隠す(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation>オブジェクトを隠す(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation>すべて表示(&amp;U)</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation>サンプルの数を変更(&amp;N)...</translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation>設定(&amp;e)...</translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation>グループ選択(&amp;G)...</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新規(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation>交点(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation>線分(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation>線分(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation>中点(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation>中点(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation>半直線(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation>半直線(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation>直線(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation>垂線(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation>垂線(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation>中心と点による円(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation>3点による弧(&amp;A)</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation>角の2等分線(&amp;B)</translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation>軌跡(&amp;o)</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation>多角形(&amp;g)</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation>扇形(&amp;e)</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation>弧形(&amp;g)</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation>円の内部(&amp;n)</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation>交点(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation>&amp;Lines</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation>平行線(&amp;L)</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation>平行線(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation>中心と半径による円(&amp;C)</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation>計測(&amp;u)</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation>距離(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation>長さ(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation>半径(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation>角度(&amp;A)</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation>割合(&amp;t)</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation>傾き(&amp;S)</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation>面積(&amp;e)</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation>計算(&amp;C)...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation>円周(&amp;C)</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation>弧の長さ(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation>変形(&amp;T)</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation>ベクトルを選択(&amp;V)</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation>ミラーを選択(&amp;M)</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation>中心を選択(&amp;C)</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation>角度を選択(&amp;A)</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation>割合を選択(&amp;o)</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation>選択を解除(&amp;l)</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation>変換(&amp;T)</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation>鏡映(&amp;e)</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation>倍率(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation>回転(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation>クイック再生(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation>ディレクトリを変更(&amp;C)...</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation>コンストラクションがありません</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation>再生(&amp;y)</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Untitled</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation>コンストラクション(&amp;r)</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation>通常オブジェクトに変更(&amp;N)</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation>既知オブジェクトに変更(&amp;G)</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation>最終オブジェクトに変更(&amp;F)</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation>初期オブジェクトに変更(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation>再帰(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>KSEG について(&amp;)...</translation>
    </message>
    <message>
        <source>kseg: Untitled</source>
        <translation>kseg: Untitled</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation>保存?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation>変更した内容を保存しますか?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>ファイルが見付かりません</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation>ファイル %1 は存在しません。.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>不正なファイル</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation>ファイル %1 は正しいKSEGファイルではないようです。</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation>言語変更</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation>言語の変更を完全に有効にするにはKSEGを再起動する必要があるかもしれません。</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation>KSEG について</translation>
    </message>
    <message>
        <source>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation type="unfinished">KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation>行:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation>列:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation>Zero-Fill</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
</TS>
